
import cv2
from rich.pretty import pprint

# Validate Imports

from validate import is_valid_directory
import glob
import re



def resize(
        source_directory: str,
        destination_directory: str,
        scale_percentage: int = None,
        width: int = None,
        height: int = None,
        prefix: str = None,
        suffix: str = None,
):
    pass


def _resize(config: dict) -> bool:
    status = False
    if config["use_key"] == "scale":
        status = resize_by_scale(
            config["file_list"],
            config["destination_directory"],
            config["scale"],
            config["interpolation"],
            config["prefix"],
            config["suffix"],
        )
    elif config["use_key"] == "dimensions":
        status = resize_by_dimension(
            config["file_list"],
            config["destination_directory"],
            config["height"],
            config["width"],
            config["interpolation"],
            config["prefix"],
            config["suffix"],
        )
    else:
        print("Invalid Option")

    return status


def resize_by_scale(input_files: list, destination_directory: str, scale: int, interpolation: int, prefix=None, suffix=None) -> bool:
    # pprint("inside resize_by_scale")
    # pprint([input_files, destination_directory, scale, interpolation, prefix, suffix])

    for file in input_files:
        image_name = file.split('/')[-1]
        image = cv2.imread(file)
        processed_image = cv2.resize(image, None, fx=scale/100, fy=scale/100, interpolation=interpolation)
        destination_file_name = f"{destination_directory}/{image_name}"
        status = cv2.imwrite(destination_file_name, processed_image)
        print(f"File Saved Status {status} for {image_name}")

    return True


def resize_by_dimension(input_files: list, destination_directory: str, height: int, width: int, interpolation: int,
                        prefix=None,  suffix=None) -> bool:
    # pprint("inside resize_by_dimension")
    # pprint([input_files, destination_directory, height, width, interpolation, prefix, suffix])

    for file in input_files:
        image_name = file.split('/')[-1]
        image = cv2.imread(file)
        processed_image = cv2.resize(image, (width, height), interpolation=interpolation)
        destination_file_name = f"{destination_directory}/{image_name}"
        status = cv2.imwrite(destination_file_name, processed_image)
        print(f"File Saved Status {status} for {image_name}")

    return True






# validate Resize






def is_valid_interpolation_flag(flag: int) -> bool:
    return flag in [0, 1, 2, 3, 4, 5, 6, 7, 8, 16]


def validate_resize_config(config: dict) -> dict:
    if not is_valid_directory(config['source_directory']):
        config["status"] = "Source Directory is not Proper"
    elif not is_valid_directory(config['destination_directory']):
        config["status"] = "Destination Directory is not Proper"
    else:

        # Source and Destination are valid directory.
        # Checking Input Options.

        if config["scale"]:
            config["use_key"] = "scale"
            config["status"] = "config_ok"
            print(f"Resizing Based on Scale : {config['scale']}")

        elif config["width"] and config["height"]:
            # The isdecimal() checks will be done by typer itself, since we mentioned as int.
            config["use_key"] = "dimensions"
            config["status"] = "config_ok"
            print(f"Resizing Based on width and height : width = {config['width']} and height = {config['height']}")

        elif config["dimensions"]:
            # Replacing all different symbol, used to delimit width and height with 'x'.
            dimensions = re.sub("[*,|]", "x", config["dimensions"].lower().strip())
            if re.match("^\d{1,5}x\d{1,5}$", dimensions):
                width, height = dimensions.split("x")
                # Try Except is not needed as we used Regex to check numbers.
                config["width"] = int(width)
                config["height"] = int(height)
                config["use_key"] = "dimensions"
                config["status"] = "config_ok"
                print(f"Resizing Based on dimensions : {dimensions}")
            else:
                config["status"] = "Dimensions are not in proper format"
                print(f"The Value of Width and/or Height is not proper : {config['dimensions']}")

        else:
            config["status"] = "Improper / Invalid Option / Insufficient Options"
            print(f"Invalid Option")

    if not is_valid_interpolation_flag(config["interpolation"]):
        config["status"] = "Invalid Interpolation Flag given"

    return config














from validate import is_valid_directory
from rich.pretty import pprint
import time
import cv2

def validate_timestamp_config(config: dict) -> dict:
    if not is_valid_directory(config['source_directory']):
        config["status"] = "Source Directory is not Proper"
    elif not is_valid_directory(config['destination_directory']):
        config["status"] = "Destination Directory is not Proper"
    else:

        if config["strftime"]:
            try:
                config["timetext"] = time.strftime(config["strftime"], time.strptime(config["timetext"]))
            except:
                print("Failed to parse the time given as input to specified format. Using the original string")

        config["status"] = "config_ok"

    return config

def _timestamp(config: dict) -> bool:
    pprint(config)
    status = timestamp_image(
        config["file_list"],
        config["destination_directory"],
        config["timetext"],
        config["origin"],
        config["colour"],
        config["fontscale"],
        config["thickness"],
        config["prefix"],
        config["suffix"],
    )
    return status


def timestamp_image(input_files: list, destination_directory: str, text: str, origin: tuple[int, int],
                   colour: tuple[int, int, int], fontscale: float, thickness: float, prefix=None, suffix=None) -> bool:
    pprint([input_files, destination_directory, text, origin, colour, fontscale, thickness, prefix, suffix])

    for file in input_files:
        image_name = file.split('/')[-1]
        base_name, extension = image_name.rsplit(".",1)
        save_file_name = f"{prefix or ''}{base_name}{suffix or ''}.{extension}"
        image = cv2.imread(file)

        if origin == (-1, -1):
            # Printing Text at bottom left
            im_height, im_width, im_colour = image.shape
            origin = (20, im_height - 20)

        processed_image = cv2.putText(
            img=image,
            text=text,
            fontFace=cv2.FONT_HERSHEY_COMPLEX,
            org=origin,
            fontScale=fontscale,
            color=colour[::-1], # Since Open CV is BGR but we use RGB
            thickness=thickness
        )
        destination_file_name = f"{destination_directory}/{save_file_name}"
        status = cv2.imwrite(destination_file_name, processed_image)
        print(f"File Saved Status {status} for {save_file_name} | {image.shape} :: {origin}")

    return True


if __name__ == '__main__':
    timestamp_image(
        ["/home/sumanth/Videos/projects/python/images/test/src/Yatin_1660656871029.jpg"],
        "/home/sumanth/Videos/projects/python/images/test/workspace/",
        "Fri Sep  9 20:25:40 2022",
        (-1, -1),
        (255, 255, 255),
        1,
        1,
        "pre1_",
        "__suf",
    )



from multiprocess import perform_multiprocessing
from process_files import get_files_list

from rich.pretty import pprint

from resize import _resize, validate_resize_config
from annotate import _annotate, validate_annotate_config
from timestamp import _timestamp, validate_timestamp_config

process_dict = {
    "annotate": _annotate,
    "resize": _resize,
    "timestamp": _timestamp,
}

validate_dict = {
    "annotate": validate_annotate_config,
    "resize": validate_resize_config,
    "timestamp": validate_timestamp_config,
}


def process_image(config: dict, process_name: str) -> list[bool]:
    # Checks
    valid_config = validate_dict[process_name](config)
    status_list = None
    if valid_config["status"] == "config_ok":
        files_list = get_files_list(config["source_directory"], config["process"])
        config["function"] = process_dict[process_name]
        # pprint(files_list)
        # pprint(valid_config)
        status_list = perform_multiprocessing(config, files_list)
    else:
        print(f"{valid_config['status']}")

    return status_list


# def resize_command(config: dict) -> list[bool]:
#     # Checks
#     valid_config = validate_resize_config(config)
#     status_list = None
#     if valid_config["status"] == "config_ok":
#         files_list = get_files_list(config["source_directory"], config["process"])
#         # pprint(files_list)
#         # pprint(valid_config)
#         config["function"] = _resize
#         status_list = perform_multiprocessing(config, files_list)
#     else:
#         print(f"{valid_config['status']}")
#
#     return status_list


def convert_images():
    return "Images Converted"

# def print_files(path:str , is_recersive:bool = False):
#     files = glob.glob(f"{path}/*")
#     return files



from numpy import array_split
from glob import iglob
import re


def get_all_images_form_directory(path: str) -> list[str]:
    all_files = iglob(f"{path}/*")
    image_files = []
    extract_extension = re.compile("\.\w{2,4}?$")
    opencv_support = ['.bmp', '.dib', '.jpeg', '.jpg', '.jpe', '.jp2', '.png', '.webp', '.pbm', '.pgm', '.ppm', '.pxm',
                      '.pnm', '.pfm', '.sr', '.ras', '.tiff', '.tif', '.exr', '.hdr', '.pic', ]
    for file in all_files:
        extension = extract_extension.search(file)
        if extension:
            if extension.group(0) in opencv_support:
                image_files.append(file)
    return image_files


def split_files(file_names: list[str], parts: int) -> list[list[str]]:
    # Converting into list of numpy Arrays

    split_file_list = [list(chunk) for chunk in array_split(file_names, parts)]
    return split_file_list


def get_files_list(path: str, parts: int):

    all_files = get_all_images_form_directory(path)
    file_list = split_files(all_files, parts)
    return file_list



if __name__ == '__main__':
    a = get_all_images_form_directory("/home/sumanth/Videos/projects/python/images/all")
    for i in split_files(a,4):
        print(i)



# import glob
# import re
#
# from logger import log
#
#
# def is_valid_directory(path: str) -> bool:
#     # TODO Implement.
#     return True
#
#
# def is_valid_interpolation_flag(flag: int) -> bool:
#     return flag in [0, 1, 2, 3, 4, 5, 6, 7, 8, 16]
#
#
# def validate_resize_config(config: dict) -> dict:
#     if not is_valid_directory(config['source_directory']):
#         config["status"] = "Source Directory is not Proper"
#     elif not is_valid_directory(config['destination_directory']):
#         config["status"] = "Destination Directory is not Proper"
#     else:
#
#         # Source and Destination are valid directory.
#         # Checking Input Options.
#
#         if config["scale"]:
#             config["use_key"] = "scale"
#             config["status"] = "config_ok"
#             print(f"Resizing Based on Scale : {config['scale']}")
#
#         elif config["width"] and config["height"]:
#             # The isdecimal() checks will be done by typer itself, since we mentioned as int.
#             config["use_key"] = "dimensions"
#             config["status"] = "config_ok"
#             print(f"Resizing Based on width and height : width = {config['width']} and height = {config['height']}")
#
#         elif config["dimensions"]:
#             # Replacing all different symbol, used to delimit width and height with 'x'.
#             dimensions = re.sub("[*,|]", "x", config["dimensions"].lower().strip())
#             if re.match("^\d{1,5}x\d{1,5}$", dimensions):
#                 width, height = dimensions.split("x")
#                 # Try Except is not needed as we used Regex to check numbers.
#                 config["width"] = int(width)
#                 config["height"] = int(height)
#                 config["use_key"] = "dimensions"
#                 config["status"] = "config_ok"
#                 print(f"Resizing Based on dimensions : {dimensions}")
#             else:
#                 config["status"] = "Dimensions are not in proper format"
#                 print(f"The Value of Width and/or Height is not proper : {config['dimensions']}")
#
#         else:
#             config["status"] = "Improper / Invalid Option / Insufficient Options"
#             print(f"Invalid Option")
#
#     if not is_valid_interpolation_flag(config["interpolation"]):
#         config["status"] = "Invalid Interpolation Flag given"
#
#     return config
#
#
# if __name__ == '__main__':
#     value = get_all_images_form_directory("/home/sumanth/Videos/projects/python/images")
#     print(value)




def is_valid_directory(path: str) -> bool:
    # TODO Implement.
    return True











# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['batchimage']

package_data = \
{'': ['*']}

install_requires = \
['opencv-python>=4.5.0,<5.0.0', 'typer>=0.6.1,<0.7.0']

entry_points = \
{'console_scripts': ['dot2dict = batchimage.batch_image_cli.py:start']}

setup_kwargs = {
    'name': 'batchimage',
    'version': '0.3.2',
    'description': 'Batch Image Converter',
    'long_description': '# Batch Image Processing\n\n\nA Python Package for Fast Parallel Processing of Images. It\'s Simple, easy and extremely fast since it uses, all the cores in your CPU. batchimage uses opencv-python as its main dependency and few python core modules.\n\n![PyPI - Python Version](https://img.shields.io/pypi/pyversions/batchimage?style=for-the-badge)\n\n### Python Package Index Badges\n\n[![PyPI](https://img.shields.io/pypi/v/batchimage?style=for-the-badge&color=gree&logo=pypi)](https://pypi.org/project/batchimage/)\n![PyPI - Downloads](https://img.shields.io/pypi/dm/batchimage?label=Downloads&style=for-the-badge)\n![PyPI - Status](https://img.shields.io/pypi/status/batchimage?label=Status&style=for-the-badge)\n![PyPI - Format](https://img.shields.io/pypi/format/batchimage?label=Format&style=for-the-badge)\n\n\n### Github Badges\n\n![GitHub last commit](https://img.shields.io/github/last-commit/insumanth/batchimage?style=for-the-badge)\n![GitHub commit activity](https://img.shields.io/github/commit-activity/y/insumanth/batchimage?style=for-the-badge)\n![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/insumanth/batchimage?style=for-the-badge)\n![Lines of code](https://img.shields.io/tokei/lines/github/insumanth/batchimage?style=for-the-badge)\n\n\n\n------------------\n## Python Package Index Install \n\n```\npip install batchimage\n```\n\n### Note :\nThis is a pre-alpha version of the package, the api will change without any notice. Please use this package with caution.\n\n<!--\nTable\n-->\n\n### Timeline for Development\n\n| Present |                              September 2022                               |                              October 2022                               | November\'22                                                                  |\n|:---:|:-------------------------------------------------------------------------:|:-----------------------------------------------------------------------:|------------------------------------------------------------------------------|\n| ![Pre-Alpha](https://img.shields.io/badge/0-PRE--ALPHA-red?style=for-the-badge) | ![Alpha](https://img.shields.io/badge/1-ALPHA-orange?style=for-the-badge) | ![Beta](https://img.shields.io/badge/2-BETA-yellow?style=for-the-badge) | ![Release](https://img.shields.io/badge/3-RELEASE-green?style=for-the-badge) |\n\n\n\n-----------------\n![Made With Python](https://forthebadge.com/images/badges/made-with-python.svg)\n![forthebadge](https://forthebadge.com/images/badges/built-with-love.svg)\n\n<!--\n<img src="https://forthebadge.com/images/badges/works-on-my-machine.svg" alt="works-on-my-machine" width="500" height="100">\n-->\n',
    'author': 'Sumanth',
    'author_email': 'sumanthreddystar@gmail.com',
    'maintainer': 'Sumanth',
    'maintainer_email': 'sumanthreddystar@gmail.com',
    'url': 'https://pypi.org/project/batchimage/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



"""
Multiprocessing Module
"""

from multiprocessing import Pool
from resize import _resize

from rich.pretty import pprint

def perform_multiprocessing(config: dict, files_list: list[str]) -> list[bool]:

    args_list = []
    status_list = []

    for files in files_list:
        args = config.copy()
        args["file_list"] = files
        args_list.append(args)

    # pprint(files_list)
    # pprint(args_list)

    process_count = len(args_list)
    call_function = config["function"]

    with Pool(process_count) as p:
        dist_work = p.imap_unordered(call_function, args_list)
        for status in dist_work:
            status_list.append(status)

    return status_list




def invalid_function(*dummy_args) -> bool:
    print("Inside Invalid Function")
    return False




# Package Imports
import typer
import os
import time

from rich.pretty import pprint

# Module Imports
from batch_image_module import process_image

from typing import Tuple

# Typer App
app = typer.Typer()

interpolation_flags = {
    "cv2.INTER_NEAREST":  0,
    "cv2.INTER_LINEAR":  1,
    "cv2.INTER_CUBIC":  2,
    "cv2.INTER_AREA":  3,
    "cv2.INTER_LANCZOS4":  4,
    "cv2.INTER_LINEAR_EXACT":  5,
    "cv2.INTER_NEAREST_EXACT":  6,
    "cv2.INTER_MAX":  7,
    "cv2.WARP_FILL_OUTLIERS":  8,
    "cv2.WARP_INVERSE_MAP=":  16,
}

# Main Command.
#
# @app.callback(
#     invoke_without_command=True,
#     hidden=True
# )
# def main(
#         default: str  = typer.Option(
#             "",
#             "--dict",
#             "-d",
#             help="Python Dictionary / Ruby Hash name",
#         ),
#     ):
#
#     """
#         Process large batches of images in parallel.
#
#         You can,
#
#                 🔹 Compress Images - 🗜️
#
#                 🔹 Convert Images  - 🔄
#
#                 🔹 Crop Images  - 🔲
#
#                 🔹 Apply Filters  - 💅
#
#                 🔹 Convert Images  - 🔄
#
#
#         \n
#
#         batchimage on Pypi           :  https://pypi.org/project/batchimage
#
#         batchimage on Github         :  https://github.com/insumanth/batchimage
#
#         Please report any issues     :  https://github.com/insumanth/batchimage/issues
#     """
#
#     print(f"Main {default}")
#


@app.command(hidden=True)
def display(
        directory_path: str,
):
    print(directory_path)
    print(print_files(directory_path))


@app.command(hidden=True)
def compress(

        source: str = typer.Argument(
            ...,
            help="Source Directory containing Image files",
            metavar="source",
            # rich_help_panel="compress",
        ),

        destination: str = typer.Argument(
            ...,
            help="Destination Directory where processed images are stored",
            metavar="destination",
            # rich_help_panel="compress",
        ),

):
    print(f"{source} \n {destination}")
    print(f"compress. Yet to be implemented")


@app.command(hidden=True)
def convert(

):
    print(f"convert. Yet to be implemented")

# Resize

'''

@app.command(
    short_help="Resize Images",
)
def resize(

        source: str = typer.Argument(
            ...,
            help="Source Directory containing Image files",
        ),

        destination: str = typer.Argument(
            ...,
            help="Destination Directory where processed images are stored",
        ),

        process: int = typer.Option(
            os.cpu_count(),
            "--process",
            "-p",
            min=1,
            max=100,
            clamp=True,
            help="Number of process to be used to parallelize the task. (Default is the Cores in machine)",
        ),

        scale_percentage: int = typer.Option(
            None,
            "--scale",
            "-s",
            min=1,
            max=100000,
            clamp=True,
            help="Scale image to the specified percentage",
        ),

        dimensions: str = typer.Option(
            None,
            "--dimensions",
            "-d",
            help="Scale image to the specified width and height in pixels - 'wxh' format  (Eg: 800x600)",
        ),

        height: int = typer.Option(
            None,
            "--height",
            "-h",
            min=1,
            max=1000000,
            clamp=True,
            help="Scale image to the specified height in pixels (width is required along with this)",
        ),

        width: int = typer.Option(
            None,
            "--width",
            "-w",
            min=1,
            max=1000000,
            clamp=True,
            help="Scale image to the specified width in pixels (height is required along with this)",
        ),

        interpolation: int = typer.Option(
            1,
            "--interpolation",
            "-i",
            min=1,
            max=16,
            clamp=True,
            rich_help_panel="Optional",
            help=f"Image Interpolation to use, (Integer as per open-cv), only 0,1,2,3,4,5,6,7,8,16 are accepted. \n {interpolation_flags} ",
        ),

        prefix: str = typer.Option(
            None,
            "--prefix",
            "-pre",
            rich_help_panel="Optional",
            help="String to be prefixed with converted files Eg:- scaled_ ",
        ),

        suffix: str = typer.Option(
            None,
            "--suffix",
            "-suf",
            rich_help_panel="Optional",
            help="String to be suffixed with converted files Eg:- _downscale",
        ),

):
    """
    Resize Images in batches based on the specified options.
    """

    resize_config = {
        "source_directory": source,
        "destination_directory": destination,
        "process": process,
        "scale": scale_percentage,
        "dimensions": dimensions,
        "height": height,
        "width": width,
        "interpolation": interpolation,
        "prefix": prefix,
        "suffix": suffix,
        "function": None,
        "is_valid": False,
        "use_key": None,
        "status": None
    }
    pprint(resize_config, expand_all=True, indent_guides=False)
    start_time = time.time()
    status = process_image(resize_config, "resize")
    end_time = time.time()
    print(status)
    print(f"The Process completed in {end_time-start_time:.10f} Seconds")

'''

# Annotate

'''



@app.command(
    short_help="Annotate Images",
)
def annotate(

        source: str = typer.Argument(
            ...,
            help="Source Directory containing Image files",
        ),

        destination: str = typer.Argument(
            ...,
            help="Destination Directory where processed images are stored",
        ),

        process: int = typer.Option(
            os.cpu_count(),
            "--process",
            "-p",
            min=1,
            max=100,
            clamp=True,
            help="Number of process to be used to parallelize the task. (Default is the Cores in machine)",
        ),

        text: str = typer.Option(
            None,
            "--text",
            "-t",
            help="Annotate image with the given text",
        ),

        colour: Tuple[int, int, int] = typer.Option(
            (255, 0, 0),
            "--colour",
            "-c",
            min=0,
            max=255,
            clamp=True,
            help="Colour to be used to annotate image specified as rgb value Eg: 255, 0, 0 (red)",
        ),

        origin: Tuple[int, int] = typer.Option(
            (100, 100),
            "--origin",
            "-o",
            help="A Tuple if x and y coordinate from which the text will start. ( X_AXIS Y_AXIS )",
        ),

        fontscale: float = typer.Option(
            1,
            "--fontscale",
            "-f",
            min=0,
            max=100,
            clamp=True,
            help="Font Size for the text",
        ),

        thickness: int = typer.Option(
            1,
            "--thickness",
            "-th",
            min=0,
            max=100,
            clamp=True,
            help="Font Thickness for the text",
        ),

        prefix: str = typer.Option(
            None,
            "--prefix",
            "-pre",
            rich_help_panel="Optional",
            help="String to be prefixed with converted files Eg:- scaled_ ",
        ),

        suffix: str = typer.Option(
            None,
            "--suffix",
            "-suf",
            rich_help_panel="Optional",
            help="String to be suffixed with converted files Eg:- _downscale",
        ),

):
    """
    Annotate Images in batches based on the specified options.
    """

    config = {
        "source_directory": source,
        "destination_directory": destination,
        "process": process,
        "text": text,
        "colour": colour,
        "origin": origin,
        "fontscale": fontscale,
        "thickness": thickness,
        "prefix": prefix,
        "suffix": suffix,
        "function": None,
        "is_valid": False,
        "use_key": None,
        "status": None
    }
    pprint(config, expand_all=True, indent_guides=False)
    start_time = time.time()
    status = process_image(config, "annotate")
    end_time = time.time()
    print(status)
    print(f"The Process completed in {end_time-start_time:.10f} Seconds")









'''


# Timestamp


'''
'''
@app.command(
    short_help="Timestamp Images",
)
def timestamp(

        source: str = typer.Argument(
            ...,
            help="Source Directory containing Image files",
        ),

        destination: str = typer.Argument(
            ...,
            help="Destination Directory where processed images are stored",
        ),

        process: int = typer.Option(
            os.cpu_count(),
            "--process",
            "-p",
            min=1,
            max=100,
            clamp=True,
            help="Number of process to be used to parallelize the task. (Default is the Cores in machine)",
        ),

        timetext: str = typer.Option(
            time.asctime(),
            "--timetext",
            "-t",
            help="Annotate image with the given Time Stamp",
        ),

        strftime: str = typer.Option(
            None,
            "--strftime",
            "-s",
            help="Format time with the given string (Eg: 'Time is : %Y-%m-%dT%H:%M:%S' )",
        ),

        colour: Tuple[int, int, int] = typer.Option(
            (255, 0, 0),
            "--colour",
            "-c",
            min=0,
            max=255,
            clamp=True,
            help="Colour to be used to annotate image specified as rgb value Eg: 255, 0, 0 (red)",
        ),

        origin: Tuple[int, int] = typer.Option(
            (-1, -1),
            "--origin",
            "-o",
            help="A Tuple if x and y coordinate from which the text will start. ( X_AXIS Y_AXIS )",
        ),

        fontscale: float = typer.Option(
            1,
            "--fontscale",
            "-f",
            min=0,
            max=100,
            clamp=True,
            help="Font Size for the text",
        ),

        thickness: int = typer.Option(
            1,
            "--thickness",
            "-th",
            min=0,
            max=100,
            clamp=True,
            help="Font Thickness for the text",
        ),


        prefix: str = typer.Option(
            None,
            "--prefix",
            "-pre",
            rich_help_panel="Optional",
            help="String to be prefixed with converted files Eg:- scaled_ ",
        ),

        suffix: str = typer.Option(
            None,
            "--suffix",
            "-suf",
            rich_help_panel="Optional",
            help="String to be suffixed with converted files Eg:- _downscale",
        ),

):
    """
    Annotate Images with timestamp in batches based on the specified options.
    """

    config = {
        "source_directory": source,
        "destination_directory": destination,
        "process": process,
        "timetext": timetext,
        "strftime": strftime,
        "colour": colour,
        "origin": origin,
        "fontscale": fontscale,
        "thickness": thickness,
        "prefix": prefix,
        "suffix": suffix,
        "function": None,
        "is_valid": False,
        "use_key": None,
        "status": None
    }
    pprint(config, expand_all=True, indent_guides=False)
    start_time = time.time()
    status = process_image(config, "timestamp")
    end_time = time.time()
    print(status)
    print(f"The Process completed in {end_time-start_time:.10f} Seconds")








'''
'''



def start() -> None:
    app()


if __name__ == "__main__":
    app()
